
#include "ClientUserJavaAdapter.h"
#include "JNIStringUtil.h"

#include "clientuser_jni.h"

/*
 * Class:     com_perforce_client_api_ClientUser
 * Method:    nNewInstance
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_com_perforce_client_api_ClientUser_nNewInstance
	(JNIEnv * env, jobject jJavaPeer)
{
	return (jint)new ClientUserJavaAdapter( env, jJavaPeer );
}


/*
 * Class:     com_perforce_client_api_ClientUser
 * Method:    nReleaseNativeGlobalRef
 * Signature: (I)V
 */
JNIEXPORT void JNICALL Java_com_perforce_client_api_ClientUser_nReleaseNativeGlobalRef
	(JNIEnv * env, jclass, jint jRef)
{
	ClientUserJavaAdapter * ref = (ClientUserJavaAdapter *)jRef;
	ref->ReleaseGlobalRef( env );
}

/*
 * Class:     com_perforce_client_api_ClientUser
 * Method:    nDeleteInstance
 * Signature: (I)V
 */
JNIEXPORT void JNICALL Java_com_perforce_client_api_ClientUser_nDeleteInstance
	(JNIEnv *, jclass, jint jRef)
{
	delete (ClientUserJavaAdapter *)jRef;
}

/*
 * Class:     com_perforce_client_api_ClientUser
 * Method:    nEdit
 * Signature: (III)V
 */
JNIEXPORT void JNICALL Java_com_perforce_client_api_ClientUser_nEdit
	(JNIEnv *, jclass, jint jRef, jint jFileSys, jint jError)
{
	ClientUserJavaAdapter * ref = (ClientUserJavaAdapter *)jRef;
	FileSys * filesysRef = (FileSys *)jFileSys;
	Error * errorRef = (Error *)jError;
	
	ref->InheritedEdit( filesysRef, errorRef );
}

/*
 * Class:     com_perforce_client_api_ClientUser
 * Method:    nDiff
 * Signature: (IIIZLjava/lang/String;I)V
 */
JNIEXPORT void JNICALL Java_com_perforce_client_api_ClientUser_nDiff
	(JNIEnv * env, jclass, jint jRef, jint jFileSys1, jint jFileSys2, jboolean doPage, jstring jDiffFlags, jint jError)
{
	ClientUserJavaAdapter * ref = (ClientUserJavaAdapter *)jRef;
	FileSys * filesys1Ref = (FileSys *)jFileSys1;
	FileSys * filesys2Ref = (FileSys *)jFileSys2;
	Error * errorRef = (Error *)jError;
	
	char * cDiffFlags = jstring_to_cstring( env, jDiffFlags );
	
	ref->InheritedDiff( filesys1Ref, filesys2Ref, doPage, cDiffFlags, errorRef );
	
	delete ( cDiffFlags );
	
}


/*
 * Class:     com_perforce_client_api_ClientUser
 * Method:    nMerge
 * Signature: (IIIIII)V
 */
JNIEXPORT void JNICALL Java_com_perforce_client_api_ClientUser_nMerge
	(JNIEnv *, jclass, jint jRef, jint jBase, jint jLeg1, jint jLeg2, jint jResult, jint jE)
{
	ClientUserJavaAdapter * ref = (ClientUserJavaAdapter *)jRef;
	FileSys * base = (FileSys *)jBase;
	FileSys * leg1 = (FileSys *)jLeg1;
	FileSys * leg2 = (FileSys *)jLeg2;
	FileSys * result = (FileSys *)jResult;
	Error * e = (Error *)jE;
	
	ref->Merge( base, leg1, leg2, result, e );
}
